/*
 *    Copyright 2018 Niek Haarman
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package com.nhaarman.acorn.notesapp.android.ui.itemlist

import android.view.View
import com.jakewharton.rxbinding3.view.clicks
import com.nhaarman.acorn.android.presentation.RestorableViewController
import com.nhaarman.acorn.notesapp.note.NoteItem
import com.nhaarman.acorn.notesapp.presentation.itemlist.ItemListContainer
import io.reactivex.Observable
import kotlinx.android.extensions.LayoutContainer
import kotlinx.android.synthetic.main.itemlist_scene.*

class ItemListViewController(
    override val view: View
) : ItemListContainer, RestorableViewController, LayoutContainer {

    override var items: List<NoteItem> = emptyList()
        set(value) {
            itemsRecyclerView.items = value
        }

    override val createClicks: Observable<Unit> by lazy {
        createButton.clicks()
    }

    override val itemClicks: Observable<NoteItem> by lazy {
        Observable
            .create<NoteItem> { emitter ->
                val listener = object : ItemsRecyclerView.ClicksListener {

                    override fun onItemClicked(item: NoteItem) {
                        emitter.onNext(item)
                    }

                    override fun onDeleteClicked(item: NoteItem) {
                    }
                }
                itemsRecyclerView.addClicksListener(listener)
                emitter.setCancellable { itemsRecyclerView.removeClicksListener(listener) }
            }
            .share()
    }

    override val deleteClicks: Observable<NoteItem> by lazy {
        Observable
            .create<NoteItem> { emitter ->
                val listener = object : ItemsRecyclerView.ClicksListener {

                    override fun onItemClicked(item: NoteItem) {
                    }

                    override fun onDeleteClicked(item: NoteItem) {
                        emitter.onNext(item)
                    }
                }
                itemsRecyclerView.addClicksListener(listener)
                emitter.setCancellable { itemsRecyclerView.removeClicksListener(listener) }
            }
            .share()
    }

    override val containerView = view
}
